package org.jaudiotagger.tag.reference;

/**
 * An enumeration of popular tagger applications
 * <p/>
 * <p>This is not meant to be a definitive list but is first attempt to document a list of taggers in order
 * for us to link nonstandard fields, and link nonstandard tagging to them
 */
public enum Tagger
{
    ITUNES,
    MEDIAPLAYER,
    WINAMP,
    MP3TAG,
    MEDIA_MONKEY,
    TAG_AND_RENAME,
    PICARD,
    JAIKOZ,
    TAGSCANNER,
    XIPH,   //standards body rather than tagger xiph.org
    FOOBAR2000,
    BEATUNES
}
